OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Табло",
    "Dashboard app" : "Приложение за Табло",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Започнете деня си информиран\n\nТаблото за управление на Nextcloud е ваша отправна точка за деня, което ви дава\nвъзможност за преглед на предстоящите ви срещи, спешни имейли, съобщения в чат,\nвходящи билети, най-новите туитове и много повече! Потребителите могат да добавят изпълними модули,\nкоито те харесват и да променят фона по свой вкус.",
    "Customize" : "Персонизиране",
    "Edit widgets" : "Редактиране на изпълнимите модули",
    "Get more widgets from the App Store" : "Вземете повече приспособления от  App Store",
    "Change background image" : "Промяна на фоновото изображение",
    "Weather service" : "Метеорологична услуга",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "За вашата поверителност данните за времето се изискват от Nextcloud  сървъра ви от ваше име, така че метеорологичната служба не получава лична информация.",
    "Weather data from Met.no" : "Данни за времето от Met.no",
    "geocoding with Nominatim" : "геокодиране с Nominatim",
    "elevation data from OpenTopoData" : " кота данни от OpenTopoData",
    "Weather" : "Време",
    "Status" : "Състояние",
    "Good morning" : "Добро утро",
    "Good morning, {name}" : "Добро утро, {name}",
    "Good afternoon" : "Добър ден",
    "Good afternoon, {name}" : "Добър ден, {name}",
    "Good evening" : "Добър вечер",
    "Good evening, {name}" : "Добър вечер, {name}",
    "Hello" : "Здравейте",
    "Hello, {name}" : "Здравейте, {name}",
    "Pick from Files" : "Избери от Файловете",
    "Default image" : "Изображение по подразбиране",
    "Plain background" : "Обикновен фон",
    "Insert from {productName}" : "Вмъкване от {productName}",
    "Show something" : "Покажи нещо",
    "Default images" : "Изображения по подразбиране"
},
"nplurals=2; plural=(n != 1);");
